Sharing with collaborators
==========================

Databasing with atomlite
------------------------

.. seealso::

    atomlite: https://atomlite.readthedocs.io/en/latest/index.html

.. toctree::
  :maxdepth: 1

  AtomliteDatabase <_autosummary/cgexplore.utilities.AtomliteDatabase>


Mapping with chemiscope
-----------------------

.. seealso::

    chemiscope: https://chemiscope.org/

.. toctree::
  :maxdepth: 1

  write_chemiscope_json <_autosummary/cgexplore.utilities.write_chemiscope_json>
  extract_property <_autosummary/cgexplore.utilities.extract_property>
